summaryrefslogtreecommitdiffhomepage
path: root/test/syscalls/syscall_test_runner.sh
diff options
context:
space:
mode:
Diffstat (limited to 'test/syscalls/syscall_test_runner.sh')
-rwxr-xr-xtest/syscalls/syscall_test_runner.sh8
1 files changed, 5 insertions, 3 deletions
diff --git a/test/syscalls/syscall_test_runner.sh b/test/syscalls/syscall_test_runner.sh
index de479f68c..4f3790137 100755
--- a/test/syscalls/syscall_test_runner.sh
+++ b/test/syscalls/syscall_test_runner.sh
@@ -20,6 +20,8 @@
set -euf -o pipefail
-# The syscall test runner binary and arguments have all been passed as arguments
-# to this shell script.
-exec "$@"
+# Get location of syscall_test_runner binary.
+readonly runner=$(find ${TEST_SRCDIR} -name syscall_test_runner)
+
+# Pass the arguments of this script directly to the runner.
+exec "${runner}" "$@"